"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../lib");
// Note : We use `pkg` instead of `package` because `package` is
// a reserved JavaScript word
exports.command = 'add <packages..>';
exports.desc = 'Add one or more package(s) to this miniapp';
const builder = (argv) => {
    return argv
        .option('dev', {
        alias: 'd',
        default: false,
        describe: 'Add this/these packages to devDependencies',
        type: 'boolean',
    })
        .option('peer', {
        alias: 'p',
        default: false,
        describe: 'Add this/these packages to peerDependencies',
        type: 'boolean',
    })
        .option('manifestId', {
        describe: 'Id of the Manifest entry to use to create this MiniApp',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ dev, manifestId, packages, peer, }) => {
    if (manifestId) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            manifestIdExists: {
                id: manifestId,
            },
        });
    }
    for (const pkg of packages) {
        ern_core_1.log.debug(`Adding package: ${pkg}`);
        await ern_core_1.MiniApp.fromCurrentPath().addDependency(ern_core_1.PackagePath.fromString(pkg), {
            dev,
            manifestId,
            peer,
        });
        ern_core_1.log.info(`Successfully added ${pkg}`);
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=add.js.map