"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../lib");
const untildify_1 = __importDefault(require("untildify"));
exports.command = 'get <descriptor> <outDir>';
exports.desc = 'Get a mobile application binary from the binary store';
const builder = (argv) => {
    return argv
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('flavor', {
        describe: 'Custom flavor of this binary',
        type: 'string',
    })
        .coerce('outDir', (p) => (0, untildify_1.default)(p))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, flavor, outDir, }) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescriptorExistInCauldron: { descriptor },
    });
    const binaryStore = await (0, ern_orchestrator_1.getBinaryStoreFromCauldron)();
    const pathToBinary = await ern_core_1.kax.task('Downloading binary from store').run(binaryStore.getBinary(descriptor, {
        flavor,
        outDir,
    }));
    ern_core_1.log.info(`${descriptor} binary ${flavor ? `[flavor: ${flavor}]` : ''} was successfuly downloaded from the store [path: ${pathToBinary}]`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=get.js.map