"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../lib");
exports.command = 'remove <descriptor>';
exports.desc = 'Remove a mobile application binary from the binary store';
const builder = (argv) => {
    return argv
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('flavor', {
        describe: 'Custom flavor of this binary',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, flavor, }) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescriptorExistInCauldron: { descriptor },
    });
    const binaryStore = await (0, ern_orchestrator_1.getBinaryStoreFromCauldron)();
    await ern_core_1.kax
        .task('Removing binary from store')
        .run(binaryStore.removeBinary(descriptor, { flavor }));
    ern_core_1.log.info(`${descriptor} binary ${flavor ? `[flavor: ${flavor}]` : ''} was successfuly removed from the store`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=remove.js.map