"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_core_1 = require("ern-core");
const lib_1 = require("../../lib");
const untildify_1 = __importDefault(require("untildify"));
exports.command = 'use <accessKey>';
exports.desc = 'Use an existing store given its access key';
const builder = (argv) => {
    return argv
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .coerce('pathToBinary', (p) => (0, untildify_1.default)(p))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ accessKey }) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        bundleStoreUrlSetInCauldron: {
            extraErrorMessage: `You should add bundleStore config in your Cauldron`,
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const bundleStoreUrl = (await cauldron.getBundleStoreConfig()).url;
    const sdk = new ern_core_1.BundleStoreSdk(bundleStoreUrl);
    const store = await sdk.getStoreByAccessKey({ accessKey });
    ern_core_1.config.set('bundlestore-id', store);
    ern_core_1.config.set('bundlestore-accesskey', accessKey);
    ern_core_1.log.info(`Now using store ${store}`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=use.js.map