"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../../lib");
exports.command = 'miniapps <miniapps..>';
exports.desc = 'Add one or more MiniApp(s) to a given native application version in the Cauldron';
const builder = (argv) => {
    return argv
        .option('containerVersion', {
        alias: 'v',
        describe: 'Version to use for generated container. If none provided, version will be patched bumped by default.',
        type: 'string',
    })
        .option('descriptor', {
        alias: 'd',
        describe: 'A complete native application descriptor',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .coerce('miniapps', (d) => d.map(ern_core_1.PackagePath.fromString))
        .option('resetCache', {
        describe: 'Indicates whether to reset the React Native cache prior to bundling',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ containerVersion, descriptor, miniapps, resetCache, }) => {
    descriptor =
        descriptor ||
            (await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)({
                onlyNonReleasedVersions: true,
            }));
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        isNewerContainerVersion: containerVersion
            ? {
                containerVersion,
                descriptor,
                extraErrorMessage: 'To avoid conflicts with previous versions, you can only use container version newer than the current one',
            }
            : undefined,
        isSupportedMiniAppOrJsApiImplVersion: {
            obj: miniapps,
        },
        miniAppNotInNativeApplicationVersionContainer: {
            descriptor,
            extraErrorMessage: 'To update MiniApp(s) use -ern cauldron update miniapps- command',
            miniApp: miniapps,
        },
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'This command cannot work on a non existing native application version',
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const cauldronCommitMessage = [
        `${miniapps.length === 1
            ? `Add ${miniapps[0]} MiniApp to ${descriptor}`
            : `Add multiple MiniApps to ${descriptor}`}`,
    ];
    await (0, ern_orchestrator_1.syncCauldronContainer)(async () => {
        for (const miniApp of miniapps) {
            cauldronCommitMessage.push(`- Add ${miniApp.basePath} MiniApp`);
        }
        await cauldron.syncContainerMiniApps(descriptor, miniapps);
    }, descriptor, cauldronCommitMessage, { containerVersion, resetCache });
    ern_core_1.log.debug(`MiniApp(s) successfully added to ${descriptor}`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=miniapps.js.map