"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../../lib");
exports.command = 'nativeapp <descriptor>';
exports.desc = 'Add a native application to the cauldron';
const builder = (argv) => {
    return argv
        .option('copyFromVersion', {
        alias: 'c',
        describe: 'Copy Cauldron data from a previous native application version',
        type: 'string',
    })
        .option('description', {
        describe: 'Description of the native application version',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('platformVersion', {
        alias: 'v',
        describe: 'Use specified platform version',
    })
        .option('config', {
        describe: 'Configuration to use for this native application version',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ config, copyFromVersion, description, descriptor, }) => {
    let cauldron;
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescritorDoesNotExistsInCauldron: {
            descriptor,
            extraErrorMessage: 'This version of the native application already exist in Cauldron.',
        },
    });
    cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    await cauldron.beginTransaction();
    if (copyFromVersion === 'none') {
        copyFromVersion = undefined;
    }
    else if (!copyFromVersion &&
        (await cauldron.isDescriptorInCauldron(new ern_core_1.AppPlatformDescriptor(descriptor.name, descriptor.platform)))) {
        const mostRecentVersion = await cauldron.getMostRecentNativeApplicationVersion(descriptor);
        if (mostRecentVersion &&
            (await (0, lib_1.askUserConfirmation)(`Do you want to copy data from version (${mostRecentVersion.name}) ?`))) {
            copyFromVersion = mostRecentVersion.name;
        }
    }
    try {
        config = config && (await (0, ern_orchestrator_1.parseJsonFromStringOrFile)(config));
    }
    catch (e) {
        throw new Error('(--config option): Invalid input');
    }
    await ern_core_1.kax.task(`Adding ${descriptor}`).run(cauldron.addNativeApplicationVersion(descriptor, {
        config,
        copyFromVersion,
        description,
    }));
    await ern_core_1.kax
        .task('Updating Cauldron')
        .run(cauldron.commitTransaction(`Add ${descriptor} native application`));
    ern_core_1.log.info(`${descriptor} successfully added to the the Cauldron`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=nativeapp.js.map