"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const lib_1 = require("../../../lib");
const ern_cauldron_api_1 = require("ern-cauldron-api");
exports.command = 'get';
exports.desc = 'Echoes configuration stored in Cauldron';
const builder = (argv) => {
    return argv
        .option('descriptor', {
        describe: 'Partial or full native application descriptor for which to get the config from (top level config if not specified)',
        type: 'string',
    })
        .coerce('descriptor', (d) => d.toAppDescriptor())
        .option('json', {
        describe: 'Output config as a single line JSON record',
        type: 'boolean',
    })
        .option('key', {
        describe: 'The config key (echoes the whole config object if not specified)',
        type: 'string',
    })
        .option('strict', {
        default: false,
        describe: 'Echoes the config strictly associated to the descriptor',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, json, key, strict, }) => {
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)({
        ignoreRequiredErnVersionMismatch: true,
        throwIfNoActiveCauldron: true,
    });
    let result;
    if (key && strict) {
        result = await cauldron.getConfigForKeyStrict(key, descriptor);
    }
    else if (key && !strict) {
        result = await cauldron.getConfigForKey(key, descriptor);
    }
    else if (!key && strict) {
        result = await cauldron.getConfigStrict(descriptor);
    }
    else if (!key && !strict) {
        result = await cauldron.getConfig(descriptor);
    }
    process.stdout.write(json ? JSON.stringify(result) : JSON.stringify(result, null, 2));
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=get.js.map