"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const lib_1 = require("../../../lib");
exports.command = 'nativeapp <descriptor>';
exports.desc = 'Remove a native application from the cauldron';
const builder = (argv) => {
    return argv
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, }) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'This command cannot remove a native application version that do not exist in Cauldron.',
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    await cauldron.beginTransaction();
    await cauldron.delConfig(descriptor);
    await cauldron.removeDescriptor(descriptor);
    await cauldron.commitTransaction(`Remove ${descriptor}`);
    ern_core_1.log.info(`${descriptor} successfully removed from the Cauldron`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=nativeapp.js.map