"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const lib_1 = require("../../../lib");
exports.command = 'dependency <descriptor>';
exports.desc = 'Get all the native dependencies of a given native application';
const builder = (argv) => {
    return argv
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('json', {
        describe: 'Output dependencies as a single line JSON array',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, json, }) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'This command cannot work on a non existing native application version',
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const dependencies = await cauldron.getNativeDependencies(descriptor);
    json
        ? process.stdout.write(JSON.stringify(dependencies))
        : dependencies.forEach((d) => ern_core_1.log.info(d.toString()));
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=dependency.js.map