"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const lib_1 = require("../../../lib");
exports.command = 'nativeapp [descriptor]';
exports.desc = 'Get a native application from the cauldron';
const builder = (argv) => {
    return argv
        .coerce('descriptor', (d) => d.toAppDescriptor())
        .option('json', {
        describe: 'Output result as a single line JSON record',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, json, }) => {
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    if (!descriptor) {
        const napDescriptors = await cauldron.getNapDescriptorStrings();
        json
            ? process.stdout.write(JSON.stringify(napDescriptors))
            : napDescriptors.forEach((n) => ern_core_1.log.info(n));
    }
    else {
        const nativeApp = await cauldron.getDescriptor(descriptor);
        process.stdout.write(json ? JSON.stringify(nativeApp) : JSON.stringify(nativeApp, null, 1));
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=nativeapp.js.map