"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../../../lib");
const ern_cauldron_api_1 = require("ern-cauldron-api");
exports.command = 'add <alias> <url> [current]';
exports.desc = 'Add a Cauldron git repository';
const builder = (argv) => {
    return argv
        .option('current', {
        default: undefined,
        describe: 'Set repo as the current Cauldron repository',
        type: 'boolean',
    })
        .option('force', {
        alias: 'f',
        describe: 'Overwrite an existing alias with the same name',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ alias, current, force, url, }) => {
    const activate = current !== null && current !== void 0 ? current : (await (0, lib_1.askUserConfirmation)(`Set ${alias} as current Cauldron repository?`));
    ern_cauldron_api_1.cauldronRepositories.add(alias, url, { activate, force });
    ern_core_1.log.info(`Added Cauldron repository ${url} with alias ${alias}`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=add.js.map