"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const lib_1 = require("../../../lib");
exports.command = 'nativeapp <descriptor> [isReleased]';
exports.desc = 'Update a native application info in cauldron';
const builder = (argv) => {
    return argv
        .option('description', {
        describe: 'Description of the native application version',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('isReleased', {
        alias: 'r',
        default: undefined,
        describe: 'true if version is released, false otherwise',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ description, descriptor, isReleased, }) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'You cannot update the release status of a non existing native application version',
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    if (isReleased !== undefined) {
        await cauldron.updateNativeAppIsReleased(descriptor, isReleased);
        ern_core_1.log.info(`Successfully updated release status of ${descriptor}`);
    }
    if (description) {
        await cauldron.addOrUpdateDescription(descriptor, description);
        ern_core_1.log.info(`Successfully updated description of ${descriptor}`);
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=nativeapp.js.map