"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const lib_1 = require("../../lib");
const treeify_1 = __importDefault(require("treeify"));
const lodash_1 = __importDefault(require("lodash"));
exports.command = 'why <dependency>';
exports.desc = 'Why is a dependency (native or JS) in the Container of a native application verstion';
const builder = (argv) => {
    return argv
        .coerce('dependency', (d) => ern_core_1.PackagePath.fromString(d))
        .option('descriptor', {
        alias: 'd',
        describe: 'A complete native application descriptor',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ dependency, descriptor, }) => {
    if (descriptor) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            napDescriptorExistInCauldron: {
                descriptor,
                extraErrorMessage: 'This command cannot work on a non existing native application version',
            },
        });
    }
    else {
        descriptor = await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)();
    }
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const lock = await cauldron.getYarnLock(descriptor, 'container');
    if (lock) {
        const tree = ern_core_1.YarnLockParser.fromContent(lock.toString()).buildDependencyTree(dependency);
        if (lodash_1.default.isEmpty(tree)) {
            ern_core_1.log.info(`${dependency} is not part of the Composite of ${descriptor}`);
        }
        else {
            ern_core_1.log.info(treeify_1.default.asTree(tree, true, true));
        }
    }
    else {
        throw new Error(`No yarn lock was found in Cauldron for ${descriptor} Container`);
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=why.js.map