"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../lib");
exports.command = 'patch';
exports.desc = 'Patch a CodePush release';
const builder = (argv) => {
    return argv
        .option('deploymentName', {
        describe: 'Deployment to release the update to',
        type: 'string',
    })
        .option('description', {
        alias: 'des',
        describe: 'Description of the changes made to the app with this release',
        type: 'string',
    })
        .option('descriptor', {
        describe: 'Full native application descriptor from which to promote a release',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('disabled', {
        alias: 'x',
        describe: 'Specifies whether this release should be immediately downloadable',
        type: 'boolean',
    })
        .option('label', {
        alias: 'l',
        describe: 'Label of the release to update',
        type: 'string',
    })
        .option('mandatory', {
        alias: 'm',
        default: false,
        describe: 'Specifies whether this release should be considered mandatory',
        type: 'boolean',
    })
        .option('rollout', {
        alias: 'r',
        describe: 'Percentage of users this release should be immediately available to',
        type: 'number',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ deploymentName, description, descriptor, disabled, label, mandatory, rollout, }) => {
    descriptor =
        descriptor ||
            (await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)({
                onlyReleasedVersions: true,
            }));
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'You cannot CodePush to a non existing native application version.',
        },
    });
    deploymentName =
        deploymentName || (await (0, lib_1.askUserForCodePushDeploymentName)(descriptor));
    label = label || (await (0, lib_1.askUserForCodePushLabel)());
    await (0, ern_orchestrator_1.performCodePushPatch)(descriptor, deploymentName, label, {
        description,
        isDisabled: disabled,
        isMandatory: mandatory,
        rollout,
    });
    ern_core_1.log.info(`Successfully patched ${descriptor} ${deploymentName} ${label}`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=patch.js.map