"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../lib");
exports.command = 'compat-check [miniapp]';
exports.desc = 'Run compatibility checks for one or more MiniApp(s) against a target native application version';
const builder = (argv) => {
    return argv
        .option('descriptor', {
        alias: 'd',
        describe: 'Full native application selector (target native application version for the push)',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .coerce('miniapp', (m) => ern_core_1.PackagePath.fromString(m))
        .option('miniapps', {
        alias: 'm',
        describe: 'A list of one or more miniapps',
        type: 'array',
    })
        .coerce('miniapps', (d) => d.map(ern_core_1.PackagePath.fromString))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, miniapp, miniapps = [], }) => {
    if (!miniapp && miniapps.length === 0) {
        miniapps.push(ern_core_1.MiniApp.fromCurrentPath().packagePath);
    }
    else if (miniapp && miniapps.length === 0) {
        miniapps.push(miniapp);
    }
    descriptor =
        descriptor || (await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)());
    for (const miniappPkgPath of miniapps) {
        const miniAppPackage = await ern_core_1.MiniApp.fromPackagePath(miniappPkgPath);
        ern_core_1.log.info(`=> ${miniAppPackage.name}`);
        await (0, ern_orchestrator_1.checkCompatibilityWithNativeApp)(miniAppPackage, descriptor.name, descriptor.platform || undefined, descriptor.version || undefined);
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=compat-check.js.map