"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../lib");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
exports.command = 'create-plugin-config <plugin>';
exports.desc = 'Create plugin configuration for the manifest';
const builder = (argv) => {
    return argv
        .coerce('plugin', (p) => ern_core_1.PackagePath.fromString(p))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
// Bump this version whenever Electrode Native plugin configuration
// offers new features or has structural changes
const manifestBaseErnVersion = '0.46.0';
const commandHandler = async ({ plugin }) => {
    if (!(await fs_extra_1.default.pathExists('manifest.json'))) {
        throw new Error(`No manifest.json file found in current directory.
Make sure this command is run from a Manifest directory.`);
    }
    const tmpDir = (0, ern_core_1.createTmpDir)();
    try {
        ern_core_1.shell.pushd(tmpDir);
        await ern_core_1.yarn.init();
        await ern_core_1.yarn.add(plugin);
    }
    finally {
        ern_core_1.shell.popd();
    }
    const pluginPath = path_1.default.join(tmpDir, 'node_modules', plugin.name);
    const conf = await ern_core_1.PluginConfigGenerator.generateFromPath({
        pluginPath,
        resolveDependencyVersion: (x) => (0, lib_1.askUserInput)({
            message: `Cannot resolve version for ${x}. Enter the version to use`,
        }),
        resolvePbxProjPath: (x) => ern_core_1.promptUtils.askUserToChooseAnOption(x, 'Select the .pbxproj associated to this plugin'),
        revolveBuildGradlePath: (x) => ern_core_1.promptUtils.askUserToChooseAnOption(x, 'Select the build.gradle associated to this plugin'),
    });
    const pluginPackageJson = await (0, ern_core_1.readPackageJson)(pluginPath);
    const pluginVersion = pluginPackageJson.version;
    const pathToPluginConfig = path_1.default.join('plugins', `ern_v${manifestBaseErnVersion}+`, `${plugin.name}_v${pluginVersion}+`);
    if (!(await fs_extra_1.default.pathExists(pathToPluginConfig))) {
        await ern_core_1.shell.mkdir('-p', pathToPluginConfig);
    }
    else {
        throw new Error(`path ${pathToPluginConfig} already exist`);
    }
    await fs_extra_1.default.writeFile(path_1.default.join(pathToPluginConfig, 'config.json'), JSON.stringify(conf.pluginConfig, null, 2).concat('\n'));
    if (conf.androidPluginSource) {
        await fs_extra_1.default.writeFile(path_1.default.join(pathToPluginConfig, conf.androidPluginSource.filename), conf.androidPluginSource.content);
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=create-plugin-config.js.map