"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../lib");
exports.command = 'align-dependencies';
exports.desc = 'Align dependencies of all GitHub based packages on a manifest id';
const builder = (argv) => {
    return argv
        .option('descriptor', {
        describe: 'Native application version containing the packages to upgrade',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('jsApiImplsOnly', {
        describe: 'Only update package.json of JS API Implementations',
        type: 'boolean',
    })
        .option('manifestId', {
        default: 'default',
        describe: 'Id of the manifest entry to use to retrieve versions to upgrade to',
        type: 'string',
    })
        .option('miniAppsOnly', {
        describe: 'Only update package.json of MiniApps',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ descriptor, jsApiImplsOnly, manifestId = 'default', miniAppsOnly, } = {}) => {
    descriptor =
        descriptor ||
            (await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)({
                onlyNonReleasedVersions: true,
            }));
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        isEnvVariableDefined: {
            extraErrorMessage: 'ERN_GITHUB_TOKEN environment variable must be set, to use `ern github` commands',
            name: 'ERN_GITHUB_TOKEN',
        },
        manifestIdExists: {
            id: manifestId,
        },
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'This command cannot work on a non existing native application version',
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const packages = await cauldron.getContainerJsPackages({
        descriptor,
        jsApiImplsOnly,
        miniAppsOnly,
        type: 'branches',
    });
    await (0, ern_orchestrator_1.alignPackageJsonOnManifest)({ manifestId, packages });
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=align-dependencies.js.map