"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../../lib");
const inquirer_1 = __importDefault(require("inquirer"));
exports.command = 'delete-ref';
exports.desc = 'Deletes a branch/tag in multiple GitHub repositories';
const builder = (argv) => {
    return argv
        .option('branch', {
        describe: 'Name of the branch to delete',
        type: 'string',
    })
        .option('descriptor', {
        describe: 'Native application version containing the packages to delete a branch/tag from',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('jsApiImplsOnly', {
        describe: 'Delete the ref for JS API Implementations only',
        type: 'boolean',
    })
        .option('miniAppsOnly', {
        describe: 'Delete the ref for MiniApps only',
        type: 'boolean',
    })
        .option('tag', {
        describe: 'Name of the tag to delete',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ branch, descriptor, jsApiImplsOnly, miniAppsOnly, tag, } = {}) => {
    if (!branch && !tag) {
        const { branchOrTag } = await inquirer_1.default.prompt([
            {
                choices: ['branch', 'tag'],
                message: 'Which type of ref to delete ?',
                name: 'branchOrTag',
                type: 'list',
            },
        ]);
        const { branchOrTagName } = await inquirer_1.default.prompt([
            {
                message: `Please input the name of the ${branchOrTag} to delete`,
                name: 'branchOrTagName',
                type: 'input',
            },
        ]);
        if (branchOrTag === 'branch') {
            branch = branchOrTagName;
        }
        else {
            tag = branchOrTagName;
        }
    }
    descriptor =
        descriptor ||
            (await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)({
                onlyNonReleasedVersions: true,
            }));
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        isEnvVariableDefined: {
            extraErrorMessage: 'ERN_GITHUB_TOKEN environment variable must be set, to use `ern github` commands',
            name: 'ERN_GITHUB_TOKEN',
        },
        napDescriptorExistInCauldron: {
            descriptor,
            extraErrorMessage: 'This command cannot work on a non existing native application version',
        },
    });
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const packages = await cauldron.getContainerJsPackages({
        descriptor,
        jsApiImplsOnly,
        miniAppsOnly,
        type: 'versions',
    });
    if (branch) {
        await (0, ern_orchestrator_1.deleteBranch)({ name: branch, packages });
    }
    else if (tag) {
        await (0, ern_orchestrator_1.deleteTag)({ name: tag, packages });
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=delete-ref.js.map