"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../../lib");
const chalk_1 = __importDefault(require("chalk"));
const lodash_1 = __importDefault(require("lodash"));
const path_1 = __importDefault(require("path"));
exports.command = 'dependencies [module]';
exports.desc = 'List the native dependencies of an Electrode Native module';
const builder = (argv) => {
    return argv
        .option('json', {
        describe: 'Output dependencies as a single line JSON record',
        type: 'boolean',
    })
        .option('manifestId', {
        describe: 'Id of the Manifest entry to use',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ module, manifestId, json, }) => {
    if (manifestId) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            manifestIdExists: {
                id: manifestId,
            },
        });
    }
    let pathToModule = process.cwd();
    if (module) {
        pathToModule = (0, ern_core_1.createTmpDir)();
        ern_core_1.shell.pushd(pathToModule);
        try {
            await ern_core_1.yarn.init();
            await ern_core_1.yarn.add(ern_core_1.PackagePath.fromString(module));
        }
        finally {
            ern_core_1.shell.popd();
        }
    }
    const dependencies = await (0, ern_core_1.findNativeDependencies)(path_1.default.join(pathToModule, 'node_modules'), { manifestId });
    if (json) {
        process.stdout.write(JSON.stringify(dependencies));
    }
    else {
        console.log(chalk_1.default.bold.yellow('Native dependencies :'));
        logDependencies(dependencies.apis, 'APIs');
        logDependencies(dependencies.nativeApisImpl, 'Native API Implementations');
        logDependencies(dependencies.thirdPartyInManifest, 'Third party declared in Manifest');
        logDependencies(dependencies.thirdPartyNotInManifest, 'Third party not declared in Manifest');
    }
};
exports.commandHandler = commandHandler;
function logDependencies(dependencies, type) {
    if (!lodash_1.default.isEmpty(dependencies)) {
        console.log(chalk_1.default.blue.bold(`=== ${type} ===`));
        for (const d of dependencies) {
            console.log(`${d.name}@${d.version}`);
        }
    }
}
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=dependencies.js.map