"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../../../lib");
const chalk_1 = __importDefault(require("chalk"));
const cli_table_1 = __importDefault(require("cli-table"));
exports.command = 'list [platformVersion]';
exports.desc = 'List supported platform plugins';
const builder = (argv) => {
    return argv
        .option('manifestId', {
        describe: 'Manifest id for which to list support plugins',
        type: 'string',
    })
        .option('platformVersion', {
        alias: 'v',
        describe: 'Specific platform version for which to list supported plugins',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ manifestId, platformVersion = ern_core_1.Platform.currentVersion, }) => {
    if (manifestId) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            manifestIdExists: {
                id: manifestId,
            },
        });
    }
    const plugins = await ern_core_1.manifest.getNativeDependencies({
        manifestId,
        platformVersion,
    });
    ern_core_1.log.info(`Platform v${platformVersion} suports the following plugins`);
    const table = new cli_table_1.default({
        colWidths: [40, 16],
        head: [chalk_1.default.cyan('Name'), chalk_1.default.cyan('Version')],
    });
    for (const plugin of plugins) {
        table.push([plugin.name, plugin.version]);
    }
    ern_core_1.log.info(table.toString());
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=list.js.map