"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../../../lib");
const chalk_1 = __importDefault(require("chalk"));
exports.command = 'search <name> [platformVersion]';
exports.desc = 'Search a plugin';
const builder = (argv) => {
    return argv
        .option('manifestId', {
        describe: 'Id of the Manifest entry in which to search plugins',
        type: 'string',
    })
        .option('platformVersion', {
        alias: 'v',
        describe: 'Specific platform version for which to list supported plugins',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ manifestId, name, platformVersion = ern_core_1.Platform.currentVersion, }) => {
    if (manifestId) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            manifestIdExists: {
                id: manifestId,
            },
        });
    }
    const plugin = await ern_core_1.manifest.getNativeDependency(ern_core_1.PackagePath.fromString(name), { manifestId, platformVersion });
    if (!plugin) {
        return ern_core_1.log.warn(`No plugin named ${name} was found for platform version ${platformVersion}`);
    }
    ern_core_1.log.info(`${chalk_1.default.yellow(plugin.name)}@${chalk_1.default.magenta(plugin.version || '?')}`);
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=search.js.map