"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const chalk_1 = __importDefault(require("chalk"));
const lib_1 = require("../../lib");
const semver_1 = __importDefault(require("semver"));
const BASE_RELEASE_URL = `https://github.com/electrode-io/electrode-native/releases/tag`;
exports.command = 'versions';
exports.desc = 'List platform versions';
const builder = (argv) => {
    return argv.epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async () => {
    ern_core_1.log.info((0, ern_core_1.tagOneLine) `
    ${chalk_1.default.green('[CURRENT]')}
    ${chalk_1.default.yellow('[INSTALLED]')}
    ${chalk_1.default.gray('[NOT INSTALLED]')}`);
    for (const version of ern_core_1.Platform.versions) {
        // Don't show versions pre 0.7.0 as it was not official public releases
        // Electrode Native initial public release was 0.7.0 so starting from
        // this version
        if (semver_1.default.lt(version, '0.7.0')) {
            continue;
        }
        if (ern_core_1.Platform.isPlatformVersionInstalled(version)) {
            if (ern_core_1.Platform.currentVersion === version) {
                ern_core_1.log.info(chalk_1.default.green(`-> v${version}\t\t`) +
                    chalk_1.default.white(`${BASE_RELEASE_URL}/v${version}`));
            }
            else {
                ern_core_1.log.info(chalk_1.default.yellow(`v${version}\t\t`) +
                    chalk_1.default.white(`${BASE_RELEASE_URL}/v${version}`));
            }
        }
        else {
            ern_core_1.log.info(chalk_1.default.gray(`v${version}\t\t`) +
                chalk_1.default.white(`${BASE_RELEASE_URL}/v${version}`));
        }
    }
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=versions.js.map