"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_container_publisher_1 = require("ern-container-publisher");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../lib");
const untildify_1 = __importDefault(require("untildify"));
exports.command = 'publish-container';
exports.desc = 'Publish a local Container';
const builder = (argv) => {
    return argv
        .option('containerPath', {
        describe: 'Local path to the Container to publish',
        type: 'string',
    })
        .coerce('containerPath', (p) => (0, untildify_1.default)(p))
        .option('extra', {
        alias: 'e',
        describe: 'Optional extra publisher configuration (json string or local/cauldron path to config file)',
        type: 'string',
    })
        .option('inPlace', {
        default: false,
        describe: 'Run the publisher directly from the container directory instead of a temporary directory',
        type: 'boolean',
    })
        .option('platform', {
        choices: ['android', 'ios'],
        demandOption: true,
        describe: 'The native platform of the Container',
        type: 'string',
    })
        .option('publisher', {
        alias: 'p',
        demandOption: true,
        describe: 'The publisher to use',
        type: 'string',
    })
        .coerce('publisher', (p) => ern_core_1.PackagePath.fromString(p))
        .option('url', {
        alias: 'u',
        describe: 'The publication url',
        type: 'string',
    })
        .option('version', {
        alias: 'v',
        default: '1.0.0',
        describe: 'Container version to use for publication',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const publisherPackageId = 'ern-container-publisher';
const commandHandler = async ({ containerPath, extra, inPlace, platform, publisher, url, version, }) => {
    containerPath =
        containerPath || ern_core_1.Platform.getContainerGenOutDirectory(platform);
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        isContainerPath: {
            extraErrorMessage: `Make sure that ${containerPath} is the root of a Container project`,
            p: containerPath,
        },
    });
    let extraObj;
    try {
        extraObj = (extra && (await (0, ern_orchestrator_1.parseJsonFromStringOrFile)(extra))) || {};
    }
    catch (e) {
        throw new Error('(--extra/-e option): Invalid input');
    }
    if (publisher.isRegistryPath &&
        !publisher.basePath.includes(publisherPackageId)) {
        publisher = publisher.version
            ? ern_core_1.PackagePath.fromString(`${publisherPackageId}-${publisher.basePath}@${publisher.version}`)
            : ern_core_1.PackagePath.fromString(`${publisherPackageId}-${publisher.basePath}`);
    }
    await (0, ern_container_publisher_1.publishContainer)({
        containerPath,
        containerVersion: version,
        extra: extraObj,
        inPlace,
        platform,
        publisher,
        url,
    });
    ern_core_1.log.info('Container published successfully');
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=publish-container.js.map