"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_api_gen_1 = require("ern-api-gen");
const ern_core_1 = require("ern-core");
const lib_1 = require("../lib");
exports.command = 'regen-api';
exports.desc = 'Regenerates an existing api';
const builder = (argv) => {
    return argv
        .option('bridgeVersion', {
        alias: 'b',
        describe: 'Bridge version to use',
    })
        .option('manifestId', {
        describe: 'Id of the Manifest entry to use',
        type: 'string',
    })
        .option('skipVersion', {
        alias: 's',
        describe: 'Do not update API version and do not publish',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ bridgeVersion, manifestId, skipVersion, }) => {
    if (manifestId) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            manifestIdExists: {
                id: manifestId,
            },
        });
    }
    const errorMessage = 'Run command #yarn info react-native-electrode-bridge versions# to get the valid bridgeVersion';
    const electrodeBridgePkg = ern_core_1.PackagePath.fromString('react-native-electrode-bridge');
    if (bridgeVersion) {
        const electrodeBridgePkgVersions = await ern_core_1.yarn.info(electrodeBridgePkg, {
            field: 'versions',
        });
        if (electrodeBridgePkgVersions &&
            !electrodeBridgePkgVersions.includes(bridgeVersion)) {
            throw new Error(`bridgeVersion ${bridgeVersion} is not valid. ${errorMessage}`);
        }
    }
    else {
        const bridgeDep = await ern_core_1.manifest.getNativeDependency(electrodeBridgePkg, {
            manifestId,
        });
        if (!bridgeDep) {
            throw new Error(`react-native-electrode-bridge is not found in manifest. Specify explicit --bridgeVersion in the command.\n ${errorMessage}`);
        }
        if (!bridgeDep.version) {
            throw new Error(`react-native-electrode-bridge version not defined. Specify explicit --bridgeVersion in the command. \n ${errorMessage}`);
        }
        bridgeVersion = bridgeDep.version;
    }
    await ern_api_gen_1.ApiGen.regenerateCode({ bridgeVersion, skipVersion });
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=regen-api.js.map