"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../lib");
const untildify_1 = __importDefault(require("untildify"));
exports.command = 'run-container-pipeline';
exports.desc = 'Run a Container pipeline';
const builder = (argv) => {
    return argv
        .option('containerPath', {
        describe: 'Local path to the Container to run through the pipeline',
        type: 'string',
    })
        .coerce('containerPath', (p) => (0, untildify_1.default)(p))
        .option('pipeline', {
        demandOption: true,
        describe: 'Path to pipeline (local or cauldron)',
        type: 'string',
    })
        .coerce('pipeline', (p) => (0, untildify_1.default)(p))
        .option('platform', {
        choices: ['android', 'ios'],
        demandOption: true,
        describe: 'The native platform of the Container',
        type: 'string',
    })
        .option('version', {
        alias: 'v',
        default: '1.0.0',
        describe: 'Container version to use for publication',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ containerPath, pipeline, platform, version, }) => {
    var _a;
    containerPath =
        containerPath || ern_core_1.Platform.getContainerGenOutDirectory(platform);
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        isContainerPath: {
            extraErrorMessage: `Make sure that ${containerPath} is the root of a Container project`,
            p: containerPath,
        },
    });
    let pipelineObj;
    try {
        pipelineObj = await (0, ern_orchestrator_1.parseJsonFromStringOrFile)(pipeline);
    }
    catch (e) {
        throw new Error('(--pipeline option): Invalid input');
    }
    if (!((_a = pipelineObj === null || pipelineObj === void 0 ? void 0 : pipelineObj.containerGenerator) === null || _a === void 0 ? void 0 : _a.pipeline)) {
        throw new Error(`Invalid pipeline configuration.
Make sure that the pipeline is an array set inside containerGenerator as illustrated below.
{
  "containerGenerator": {
    "pipeline": [
    ]
  }
}`);
    }
    await ern_core_1.kax.task('Running Container pipeline').run((0, ern_orchestrator_1.runContainerPipeline)({
        containerPath,
        containerVersion: version,
        pipeline: pipelineObj.containerGenerator.pipeline,
        platform,
    }));
    ern_core_1.kax.task('Container pipeline successfully run').succeed();
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=run-container-pipeline.js.map