"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const lib_1 = require("../lib");
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
exports.command = 'run-ios';
exports.desc = 'Run one or more MiniApps in the iOS Runner application';
const builder = (argv) => {
    return argv
        .option('baseComposite', {
        describe: 'Base Composite',
        type: 'string',
    })
        .coerce('baseComposite', (d) => ern_core_1.PackagePath.fromString(d))
        .option('descriptor', {
        alias: 'd',
        describe: 'Full native application descriptor',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('dev', {
        default: true,
        describe: 'Enable or disable React Native dev support',
        type: 'boolean',
    })
        .option('extra', {
        alias: 'e',
        describe: 'Optional extra run configuration (json string or local/cauldron path to config file)',
        type: 'string',
    })
        .option('host', {
        describe: 'Host/IP to use for the local packager',
        type: 'string',
    })
        .option('launchArgs', {
        describe: 'Arguments to pass to the application when launching it',
        type: 'string',
    })
        .option('launchEnvVars', {
        describe: 'Environment variables to pass to the application when launching it (space separated key=value pairs)',
    })
        .option('mainMiniAppName', {
        describe: 'Name of the MiniApp to launch when starting the Runner application',
        type: 'string',
    })
        .option('miniapps', {
        alias: 'm',
        describe: 'One or more MiniApps to combine in the Runner Container',
        type: 'array',
    })
        .coerce('miniapps', (d) => d.map(ern_core_1.PackagePath.fromString))
        .option('port', {
        default: '8081',
        describe: 'Port to use for the local package',
        type: 'string',
    })
        .option('usePreviousDevice', {
        alias: 'u',
        describe: 'Use the previously selected device to avoid prompt',
        type: 'boolean',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ baseComposite, descriptor, dev, extra, host, launchArgs, launchEnvVars, mainMiniAppName, miniapps, port, usePreviousDevice, }) => {
    if (process.platform !== 'darwin') {
        return ern_core_1.log.error('This command is only supported on macOS');
    }
    ern_core_1.deviceConfig.updateDeviceConfig('ios', usePreviousDevice);
    if (!host && dev) {
        try {
            host = (0, ern_core_1.getLocalIp)();
        }
        catch (e) {
            // Swallow
            ern_core_1.log.debug(e);
        }
    }
    const miniAppPackageJson = await (0, ern_core_1.readPackageJson)(process.cwd());
    let extraObj;
    try {
        extraObj = extra && (await (0, ern_orchestrator_1.parseJsonFromStringOrFile)(extra));
    }
    catch (e) {
        throw new Error('(--extra/-e option): Invalid input');
    }
    extraObj = extraObj !== null && extraObj !== void 0 ? extraObj : (miniAppPackageJson.ern ? miniAppPackageJson.ern : {});
    await (0, ern_orchestrator_1.runMiniApp)('ios', {
        baseComposite,
        descriptor,
        dev,
        extra: extraObj,
        host: host || 'localhost',
        launchArgs,
        launchEnvVars,
        mainMiniAppName,
        miniapps,
        port,
    });
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=run-ios.js.map