"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const lib_1 = require("../lib");
const ern_orchestrator_1 = require("ern-orchestrator");
const ern_core_1 = require("ern-core");
const untildify_1 = __importDefault(require("untildify"));
exports.command = 'start';
exports.desc = 'Start a composite MiniApp';
const builder = (argv) => {
    return argv
        .option('activityName', {
        alias: 'a',
        describe: 'Android Activity to launch',
        type: 'string',
    })
        .option('baseComposite', {
        describe: 'Base Composite',
        type: 'string',
    })
        .coerce('baseComposite', (d) => ern_core_1.PackagePath.fromString(d))
        .option('bundleId', {
        alias: 'b',
        describe: 'iOS Bundle Identifier',
        type: 'string',
    })
        .option('compositeDir', {
        describe: 'Directory in which to generate the composite',
        type: 'string',
    })
        .coerce('compositeDir', (p) => (0, untildify_1.default)(p))
        .option('descriptor', {
        alias: 'd',
        describe: 'Full native application selector',
        type: 'string',
    })
        .coerce('descriptor', (d) => ern_core_1.AppVersionDescriptor.fromString(d))
        .option('extraJsDependencies', {
        alias: 'e',
        describe: 'Additional JavaScript dependencies to add to the composite JavaScript bundle',
        type: 'array',
    })
        .coerce('extraJsDependencies', (d) => d.map(ern_core_1.PackagePath.fromString))
        .option('jsApiImpls', {
        describe: 'A list of one or more JS API Implementation(s)',
        type: 'array',
    })
        .coerce('jsApiImpls', (d) => d.map(ern_core_1.PackagePath.fromString))
        .option('flavor', {
        describe: 'Custom binary flavor',
    })
        .option('launchArgs', {
        describe: '[iOS] Arguments to pass to the application when launching it',
        type: 'string',
    })
        .option('launchEnvVars', {
        describe: '[iOS] Environment variables to pass to the application when launching it (space separated key=value pairs)',
    })
        .option('launchFlags', {
        describe: '[Android] Flags to pass to the application when launching it',
        type: 'string',
    })
        .option('miniapps', {
        alias: 'm',
        describe: 'A list of one or more MiniApp(s)',
        type: 'array',
    })
        .coerce('miniapps', (d) => d.map(ern_core_1.PackagePath.fromString))
        .option('packageName', {
        alias: 'p',
        describe: 'Android application package name',
        type: 'string',
    })
        .option('watchNodeModules', {
        alias: 'w',
        describe: 'A list of one or more directory name from node_modules that should be watched for changes',
        type: 'array',
    })
        .option('disableBinaryStore', {
        describe: 'Disable automatic retrieval of the binary from the Binary Store',
        type: 'boolean',
    })
        .option('host', {
        describe: 'Host/IP to use for the local packager',
        type: 'string',
    })
        .option('port', {
        default: '8081',
        describe: 'Port to use for the local package',
        type: 'string',
    })
        .option('resetCache', {
        describe: 'Indicates whether to reset the React Native cache prior to bundling',
        type: 'boolean',
    })
        .group(['activityName', 'launchFlags', 'packageName'], 'Android binary launch options:')
        .group(['bundleId', 'launchEnvVars', 'launchArgs'], 'iOS binary launch options:')
        .group(['disableBinaryStore', 'flavor'], 'Binary store specific options:')
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ activityName, baseComposite, bundleId, compositeDir, descriptor, extraJsDependencies = [], flavor, host, jsApiImpls, launchArgs, launchEnvVars, launchFlags, miniapps, packageName, port, watchNodeModules, disableBinaryStore, resetCache, } = {}) => {
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        metroServerIsNotRunning: {
            extraErrorMessage: `You should kill the current server before running this command.`,
            host: host || 'localhost',
            port: port || '8081',
        },
    });
    if (!miniapps && !descriptor) {
        descriptor = await (0, lib_1.askUserToChooseANapDescriptorFromCauldron)();
    }
    await (0, ern_orchestrator_1.start)({
        activityName,
        baseComposite,
        bundleId,
        compositeDir,
        descriptor,
        disableBinaryStore,
        extraJsDependencies,
        flavor,
        host,
        jsApiImpls,
        launchArgs,
        launchEnvVars,
        launchFlags,
        miniapps,
        packageName,
        port,
        resetCache,
        watchNodeModules,
    });
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=start.js.map