"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const ern_container_transformer_1 = require("ern-container-transformer");
const ern_orchestrator_1 = require("ern-orchestrator");
const lib_1 = require("../lib");
const untildify_1 = __importDefault(require("untildify"));
exports.command = 'transform-container';
exports.desc = 'Transform a local Container';
const builder = (argv) => {
    return argv
        .option('containerPath', {
        describe: 'Local path to the Container to transform',
        type: 'string',
    })
        .coerce('untildify', (p) => (0, untildify_1.default)(p))
        .option('extra', {
        alias: 'e',
        describe: 'Optional extra transformer configuration (json string or local/cauldron path to config file)',
        type: 'string',
    })
        .option('platform', {
        alias: 'p',
        describe: 'Native platform of the Container',
        type: 'string',
    })
        .option('transformer', {
        alias: 't',
        describe: 'Transformer to use',
        type: 'string',
    })
        .coerce('transformer', (t) => ern_core_1.PackagePath.fromString(t))
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const transformerPackageId = 'ern-container-transformer';
const commandHandler = async ({ containerPath, extra, platform, transformer, }) => {
    containerPath =
        containerPath || ern_core_1.Platform.getContainerGenOutDirectory(platform);
    await (0, lib_1.logErrorAndExitIfNotSatisfied)({
        isContainerPath: {
            extraErrorMessage: `Make sure that ${containerPath} is the root of a Container project`,
            p: containerPath,
        },
    });
    let extraObj;
    try {
        extraObj = (extra && (await (0, ern_orchestrator_1.parseJsonFromStringOrFile)(extra))) || {};
    }
    catch (e) {
        throw new Error('(--extra/-e option): Invalid input');
    }
    if (transformer.isRegistryPath &&
        !transformer.basePath.includes(transformerPackageId)) {
        transformer = transformer.version
            ? ern_core_1.PackagePath.fromString(`${transformerPackageId}-${transformer.basePath}@${transformer.version}`)
            : ern_core_1.PackagePath.fromString(`${transformerPackageId}-${transformer.basePath}`);
    }
    await (0, ern_container_transformer_1.transformContainer)({
        containerPath,
        extra: extraObj,
        platform,
        transformer,
    });
    ern_core_1.log.info('Container transformed successfully');
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=transform-container.js.map