"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.commandHandler = exports.builder = exports.desc = exports.command = void 0;
const ern_core_1 = require("ern-core");
const lib_1 = require("../lib");
exports.command = 'upgrade-miniapp';
exports.desc = 'Upgrade a MiniApp to current or specific platform version';
const builder = (argv) => {
    return argv
        .option('version', {
        alias: 'v',
        describe: 'Specific platform version to upgrade MiniApp to',
        type: 'string',
    })
        .option('manifestId', {
        describe: 'Id of the manifest entry to use to retrieve versions to upgrade to',
        type: 'string',
    })
        .epilog((0, lib_1.epilog)(exports));
};
exports.builder = builder;
const commandHandler = async ({ manifestId, version, }) => {
    if (manifestId) {
        await (0, lib_1.logErrorAndExitIfNotSatisfied)({
            manifestIdExists: {
                id: manifestId,
            },
        });
    }
    const miniApp = ern_core_1.MiniApp.fromCurrentPath();
    const versionWithoutPrefix = version && version.toString().replace('v', '');
    await miniApp.upgrade({ manifestId, platformVersion: versionWithoutPrefix });
};
exports.commandHandler = commandHandler;
exports.handler = (0, lib_1.tryCatchWrap)(exports.commandHandler);
//# sourceMappingURL=upgrade-miniapp.js.map