"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.askUserToChooseANapDescriptorFromCauldron = void 0;
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_core_1 = require("ern-core");
const lodash_1 = __importDefault(require("lodash"));
const inquirer_1 = __importDefault(require("inquirer"));
//
// Inquire user to choose a native application version from the Cauldron, optionally
// filtered by platform/and or release status and returns the selected one as a string
async function askUserToChooseANapDescriptorFromCauldron({ platform, onlyReleasedVersions, onlyNonReleasedVersions, message, } = {}) {
    const cauldron = await (0, ern_cauldron_api_1.getActiveCauldron)();
    const napDescriptorStrings = await cauldron.getNapDescriptorStrings({
        onlyNonReleasedVersions,
        onlyReleasedVersions,
        platform,
    });
    if (lodash_1.default.isEmpty(napDescriptorStrings)) {
        throw new Error('Could not find any qualifying native application version in the Cauldron');
    }
    const { userSelectedCompleteNapDescriptor } = await inquirer_1.default.prompt([
        {
            choices: napDescriptorStrings,
            message: message || 'Choose a native application version',
            name: 'userSelectedCompleteNapDescriptor',
            type: 'list',
        },
    ]);
    return ern_core_1.AppVersionDescriptor.fromString(userSelectedCompleteNapDescriptor);
}
exports.askUserToChooseANapDescriptorFromCauldron = askUserToChooseANapDescriptorFromCauldron;
//# sourceMappingURL=askUserToChooseANapDescriptorFromCauldron.js.map