"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logErrorAndExitIfNotSatisfied = void 0;
const ern_core_1 = require("ern-core");
const ern_orchestrator_1 = require("ern-orchestrator");
async function logErrorAndExitIfNotSatisfied({ noGitOrFilesystemPath, noFileSystemPath, isNewerContainerVersion, napDescriptorExistInCauldron, sameNativeApplicationAndPlatform, napDescritorDoesNotExistsInCauldron, publishedToNpm, miniAppNotInNativeApplicationVersionContainer, miniAppIsInNativeApplicationVersionContainer, miniAppIsInNativeApplicationVersionContainerWithDifferentVersion, dependencyNotInNativeApplicationVersionContainer, dependencyIsOrphaned, dependencyIsInNativeApplicationVersionContainer, dependencyIsInNativeApplicationVersionContainerWithDifferentVersion, dependencyNotInUseByAMiniApp, cauldronIsActive, isValidNpmPackageName, isValidElectrodeNativeModuleName, checkIfCodePushOptionsAreValid, isFilePath, isDirectoryPath, pathExist, isValidPlatformConfig, isSupportedMiniAppOrJsApiImplVersion, isContainerPath, isEnvVariableDefined, manifestIdExists, bundleStoreUrlSetInCauldron, bundleStoreAccessKeyIsSet, metroServerIsNotRunning, } = {}) {
    let kaxTask;
    try {
        if (cauldronIsActive) {
            kaxTask = ern_core_1.kax.task('Ensuring that a Cauldron is active');
            await ern_orchestrator_1.Ensure.cauldronIsActive(cauldronIsActive.extraErrorMessage);
            kaxTask.succeed();
        }
        if (isNewerContainerVersion) {
            kaxTask = ern_core_1.kax.task('Ensuring that container version is newer compared to the current one');
            await ern_orchestrator_1.Ensure.isNewerContainerVersion(isNewerContainerVersion.descriptor, isNewerContainerVersion.containerVersion, isNewerContainerVersion.extraErrorMessage);
            kaxTask.succeed();
        }
        if (noGitOrFilesystemPath) {
            kaxTask = ern_core_1.kax.task('Ensuring that not git or file system path(s) is/are used');
            ern_orchestrator_1.Ensure.noGitOrFilesystemPath(noGitOrFilesystemPath.obj, noGitOrFilesystemPath.extraErrorMessage);
            kaxTask.succeed();
        }
        if (noFileSystemPath) {
            kaxTask = ern_core_1.kax.task('Ensuring that no file system path(s) is/are used');
            ern_orchestrator_1.Ensure.noFileSystemPath(noFileSystemPath.obj, noFileSystemPath.extraErrorMessage);
            kaxTask.succeed();
        }
        if (napDescriptorExistInCauldron) {
            kaxTask = ern_core_1.kax.task('Ensuring that native application descriptor exists in Cauldron');
            await ern_orchestrator_1.Ensure.napDescritorExistsInCauldron(napDescriptorExistInCauldron.descriptor, napDescriptorExistInCauldron.extraErrorMessage);
            kaxTask.succeed();
        }
        if (sameNativeApplicationAndPlatform) {
            kaxTask = ern_core_1.kax.task('Ensuring that all descriptors are for the same native application and platform');
            ern_orchestrator_1.Ensure.sameNativeApplicationAndPlatform(sameNativeApplicationAndPlatform.descriptors, sameNativeApplicationAndPlatform.extraErrorMessage);
            kaxTask.succeed();
        }
        if (napDescritorDoesNotExistsInCauldron) {
            kaxTask = ern_core_1.kax.task('Ensuring that native application descriptor does not already exist in Cauldron');
            await ern_orchestrator_1.Ensure.napDescritorDoesNotExistsInCauldron(napDescritorDoesNotExistsInCauldron.descriptor, napDescritorDoesNotExistsInCauldron.extraErrorMessage);
            kaxTask.succeed();
        }
        if (publishedToNpm) {
            kaxTask = ern_core_1.kax.task('Ensuring that package(s) version(s) have been published to npm');
            await ern_orchestrator_1.Ensure.publishedToNpm(publishedToNpm.obj, publishedToNpm.extraErrorMessage);
            kaxTask.succeed();
        }
        if (miniAppNotInNativeApplicationVersionContainer) {
            kaxTask = ern_core_1.kax.task('Ensuring that MiniApp(s) is/are not present in native application version container');
            await ern_orchestrator_1.Ensure.miniAppNotInNativeApplicationVersionContainer(miniAppNotInNativeApplicationVersionContainer.miniApp, miniAppNotInNativeApplicationVersionContainer.descriptor, miniAppNotInNativeApplicationVersionContainer.extraErrorMessage);
            kaxTask.succeed();
        }
        if (miniAppIsInNativeApplicationVersionContainer) {
            kaxTask = ern_core_1.kax.task('Ensuring that MiniApp(s) is/are present in native application version container');
            await ern_orchestrator_1.Ensure.miniAppIsInNativeApplicationVersionContainer(miniAppIsInNativeApplicationVersionContainer.miniApp, miniAppIsInNativeApplicationVersionContainer.descriptor, miniAppIsInNativeApplicationVersionContainer.extraErrorMessage);
            kaxTask.succeed();
        }
        if (miniAppIsInNativeApplicationVersionContainerWithDifferentVersion) {
            kaxTask = ern_core_1.kax.task('Ensuring that MiniApp(s) is/are present in native application version container with different version(s)');
            await ern_orchestrator_1.Ensure.miniAppIsInNativeApplicationVersionContainerWithDifferentVersion(miniAppIsInNativeApplicationVersionContainerWithDifferentVersion.miniApp, miniAppIsInNativeApplicationVersionContainerWithDifferentVersion.descriptor, miniAppIsInNativeApplicationVersionContainerWithDifferentVersion.extraErrorMessage);
            kaxTask.succeed();
        }
        if (dependencyNotInNativeApplicationVersionContainer) {
            kaxTask = ern_core_1.kax.task('Ensuring that dependency(ies) is/are not present in native application version container');
            await ern_orchestrator_1.Ensure.dependencyNotInNativeApplicationVersionContainer(dependencyNotInNativeApplicationVersionContainer.dependency, dependencyNotInNativeApplicationVersionContainer.descriptor, dependencyNotInNativeApplicationVersionContainer.extraErrorMessage);
            kaxTask.succeed();
        }
        if (dependencyIsInNativeApplicationVersionContainer) {
            kaxTask = ern_core_1.kax.task('Ensuring that dependency(ies) is/are present in native application version container');
            await ern_orchestrator_1.Ensure.dependencyIsInNativeApplicationVersionContainer(dependencyIsInNativeApplicationVersionContainer.dependency, dependencyIsInNativeApplicationVersionContainer.descriptor, dependencyIsInNativeApplicationVersionContainer.extraErrorMessage);
            kaxTask.succeed();
        }
        if (dependencyIsInNativeApplicationVersionContainerWithDifferentVersion) {
            kaxTask = ern_core_1.kax.task('Ensuring that dependency(ies) is/are present in native application version container with different version(s)');
            await ern_orchestrator_1.Ensure.dependencyIsInNativeApplicationVersionContainerWithDifferentVersion(dependencyIsInNativeApplicationVersionContainerWithDifferentVersion.dependency, dependencyIsInNativeApplicationVersionContainerWithDifferentVersion.descriptor, dependencyIsInNativeApplicationVersionContainerWithDifferentVersion.extraErrorMessage);
            kaxTask.succeed();
        }
        if (dependencyNotInUseByAMiniApp) {
            kaxTask = ern_core_1.kax.task('Ensuring that no MiniApp(s) is/are using a dependency');
            await ern_orchestrator_1.Ensure.dependencyNotInUseByAMiniApp(dependencyNotInUseByAMiniApp.dependency, dependencyNotInUseByAMiniApp.descriptor, dependencyNotInUseByAMiniApp.extraErrorMessage);
            kaxTask.succeed();
        }
        if (dependencyIsOrphaned) {
            kaxTask = ern_core_1.kax.task('Ensuring that depedency/dependencies is/are orphaned');
            await ern_orchestrator_1.Ensure.dependencyIsOrphaned(dependencyIsOrphaned.dependency, dependencyIsOrphaned.descriptor, dependencyIsOrphaned.extraErrorMessage);
            kaxTask.succeed();
        }
        if (isValidNpmPackageName) {
            kaxTask = ern_core_1.kax.task('Ensuring that npm package name is valid');
            await ern_orchestrator_1.Ensure.isValidNpmPackageName(isValidNpmPackageName.name, isValidNpmPackageName.extraErrorMessage);
            kaxTask.succeed();
        }
        if (isValidElectrodeNativeModuleName) {
            kaxTask = ern_core_1.kax.task('Ensuring that Electrode Native module name is valid');
            await ern_orchestrator_1.Ensure.isValidElectrodeNativeModuleName(isValidElectrodeNativeModuleName.name, isValidElectrodeNativeModuleName.extraErrorMessage);
            kaxTask.succeed();
        }
        if (checkIfCodePushOptionsAreValid) {
            kaxTask = ern_core_1.kax.task('Ensuring that preconditions for code-push command are valid');
            ern_orchestrator_1.Ensure.checkIfCodePushOptionsAreValid(checkIfCodePushOptionsAreValid.descriptors, checkIfCodePushOptionsAreValid.targetBinaryVersion, checkIfCodePushOptionsAreValid.semVerDescriptor, checkIfCodePushOptionsAreValid.extraErrorMessage);
            kaxTask.succeed();
        }
        if (pathExist) {
            kaxTask = ern_core_1.kax.task('Ensuring that path exist');
            await ern_orchestrator_1.Ensure.pathExist(pathExist.p);
            kaxTask.succeed();
        }
        if (isFilePath) {
            kaxTask = ern_core_1.kax.task('Ensuring that path is a file path');
            await ern_orchestrator_1.Ensure.isFilePath(isFilePath.p, isFilePath.extraErrorMessage);
            kaxTask.succeed();
        }
        if (isDirectoryPath) {
            kaxTask = ern_core_1.kax.task('Ensuring that path is a directory path');
            await ern_orchestrator_1.Ensure.isDirectoryPath(isDirectoryPath.p, isDirectoryPath.extraErrorMessage);
            kaxTask.succeed();
        }
        if (isValidPlatformConfig) {
            kaxTask = ern_core_1.kax.task('Ensuring that config key is whitelisted');
            ern_orchestrator_1.Ensure.isValidPlatformConfig(isValidPlatformConfig.key);
            kaxTask.succeed();
        }
        if (isSupportedMiniAppOrJsApiImplVersion) {
            kaxTask = ern_core_1.kax.task('Ensuring that version is fixed');
            ern_orchestrator_1.Ensure.isSupportedMiniAppOrJsApiImplVersion(isSupportedMiniAppOrJsApiImplVersion.obj);
            kaxTask.succeed();
        }
        if (isContainerPath) {
            kaxTask = ern_core_1.kax.task('Ensuring that path is a container path');
            ern_orchestrator_1.Ensure.isContainerPath(isContainerPath.p, isContainerPath.extraErrorMessage);
            kaxTask.succeed();
        }
        if (isEnvVariableDefined) {
            kaxTask = ern_core_1.kax.task(`Ensuring that ${isEnvVariableDefined.name} env variable is defined`);
            ern_orchestrator_1.Ensure.isEnvVariableDefined(isEnvVariableDefined.name, isEnvVariableDefined.extraErrorMessage);
            kaxTask.succeed();
        }
        if (manifestIdExists) {
            kaxTask = ern_core_1.kax.task(`Ensuring that ${manifestIdExists.id} id exists in Manifest(s)`);
            await ern_orchestrator_1.Ensure.manifestIdExists(manifestIdExists.id, manifestIdExists.extraErrorMessage);
            kaxTask.succeed();
        }
        if (bundleStoreUrlSetInCauldron) {
            kaxTask = ern_core_1.kax.task(`Ensuring that bundleStore url is set in Cauldron`);
            await ern_orchestrator_1.Ensure.bundleStoreUrlSetInCauldron(bundleStoreUrlSetInCauldron.extraErrorMessage);
            kaxTask.succeed();
        }
        if (bundleStoreAccessKeyIsSet) {
            kaxTask = ern_core_1.kax.task(`Ensuring that bundlestore-accesskey is set in configuration`);
            await ern_orchestrator_1.Ensure.bundleStoreAccessKeyIsSet(bundleStoreAccessKeyIsSet.extraErrorMessage);
            kaxTask.succeed();
        }
        if (metroServerIsNotRunning) {
            kaxTask = ern_core_1.kax.task(`Ensuring that metro server is not running`);
            await ern_orchestrator_1.Ensure.metroServerIsNotRunning(metroServerIsNotRunning.host, metroServerIsNotRunning.port, metroServerIsNotRunning.extraErrorMessage);
            kaxTask.succeed();
        }
    }
    catch (e) {
        kaxTask.fail();
        ern_core_1.utils.logErrorAndExitProcess(e, 1);
    }
}
exports.logErrorAndExitIfNotSatisfied = logErrorAndExitIfNotSatisfied;
//# sourceMappingURL=logErrorAndExitIfNotSatisfied.js.map