"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseArgValue = void 0;
const ern_cauldron_api_1 = require("ern-cauldron-api");
const ern_orchestrator_1 = require("ern-orchestrator");
const fs_extra_1 = __importDefault(require("fs-extra"));
/**
 * Parse a yargs arg value to return its real representation
 * Yargs as it is configured will only detect args as number or string
 * types.
 * This function will return the real typed value as follow :
 * - If value is of type 'number' return the value as such
 * - If value is the string 'true' or 'false' return the boolean representation
 * - If value is a string indicating a path to a file, return parseJsonFromStringOrFile result
 * - If value is a string indication a path to a file in cauldron, return parseJsonFromStringOrFile result
 * - Otherwise just try to parse the string as json and return the object, or if it fails just return the original value
 * @param v The value to parse
 */
async function parseArgValue(v) {
    if (typeof v === 'number') {
        return v;
    }
    else if (v.startsWith(ern_cauldron_api_1.cauldronFileUriScheme)) {
        return (0, ern_orchestrator_1.parseJsonFromStringOrFile)(v);
    }
    else if (v === 'true') {
        return true;
    }
    else if (v === 'false') {
        return false;
    }
    else if (await fs_extra_1.default.pathExists(v)) {
        return (0, ern_orchestrator_1.parseJsonFromStringOrFile)(v);
    }
    else {
        try {
            return JSON.parse(v);
        }
        catch (e) {
            return v;
        }
    }
}
exports.parseArgValue = parseArgValue;
//# sourceMappingURL=parseArgValue.js.map